package Grid::GPT::Locations;


my ($prefix, $globus_prefix, $exec_prefix, $bindir, $sbindir, $libdir);
my ($datarootdir, $datadir, $perlmoduledir, $gptdatadir);
my ($gptexecsharedir, $amdir, $pkg_confdir, $aclocaldir);

if (exists $ENV{GPT_LOCATION})
{
    $prefix = $ENV{GPT_LOCATION};
}
else
{
    $prefix = "/scratch/dschultz/globus";
}

if (exists $ENV{GLOBUS_LOCATION})
{
    $globus_prefix = $ENV{GLOBUS_LOCATION};
}
else
{
    $globus_prefix = "/scratch/dschultz/globus";
}

$exec_prefix = "${prefix}";
$bindir = "${exec_prefix}/bin";
$sbindir = "${exec_prefix}/sbin";
$libdir = "${exec_prefix}/lib64";
$datarootdir = "${prefix}/share";
$datadir = "${prefix}/share";
$perlmoduledir = "/scratch/dschultz/globus/lib/perl";
$gptdatadir = "${datadir}/globus/gpt";
$gptexecsharedir = "${datadir}/globus/gpt";
$amdir = "${datadir}/globus/amdir";
$pkg_confdir = "${datadir}/globus/gpt";
$aclocaldir = "${datadir}/globus/aclocal";

unshift(@INC, "${perlmoduledir}");

use strict;
use Carp;
use Cwd;

require Exporter;
use vars       qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);

# set the version for version checking
$VERSION     = 0.01;

@ISA = qw(Exporter);

require Grid::GPT::FilelistFunctions; 

sub new
{
  my ($that, %args)  = @_;
  my $class = ref($that) || $that;

  my $me  = {
             tmpdir => $args{'tmpdir'},
             builddir => $args{'builddir'},
             bindir => $args{'bindir'},
             srcdir => $args{'srcdir'},
             installdir => $args{'installdir'},
             gpt_etcdir => undef,
             gpt_amdir => undef,
             gpt_aclocaldir => undef,
             gptexecsharedir => undef,
             pkgdir => undef,
             coredir => undef,
             bundledir => undef,
             setupdir => undef,
             pkg_confdir => undef
            };
  
  bless $me, $class;
  $me->_init();
  return $me;
}

sub _init {
  my ($me) =@_;

  $me->_init_installdirs();
  $me->_init_builddir();
  $me->_init_tmpdir();
  $me->_init_gptdir();

  for my $d ('tmpdir',
             'builddir',
             'bindir',
             'srcdir',
             'installdir',
             'pkgdir',
             'bundledir',
             'setupdir') {

    next if ! defined $me->{$d};
    $me->{$d} = Grid::GPT::FilelistFunctions::abspath($me->{$d});
  }
}

sub _init_gptdir {
  my ($me) =@_;

  $me->{'gpt_etcdir'} = "$gptdatadir";
  $me->{'gpt_amdir'} = "$amdir";
  $me->{'gpt_aclocaldir'} = "$aclocaldir";
  $me->{'gptexecsharedir'} = "$gptexecsharedir";
}

sub _init_tmpdir {
  my ($me) =@_;
  my $tmpdir= defined $me->{'tmpdir'} ? $me->{'tmpdir'} : "/tmp";

  my $time=time();
  my $tmpd=$tmpdir."/"."gpt-"."$$"."-".$time;
  $tmpdir=$tmpd;

  $me->{'tmpdir'} = $tmpd;
}

sub create_dirs {
  my ($me, %args) = @_;

  if ($args{'mode'} eq 'install' ) {
    Grid::GPT::FilelistFunctions::mkinstalldir($me->{'bundledir'});
    Grid::GPT::FilelistFunctions::mkinstalldir($me->{'setupdir'});
    my $amdir = $me->{'gpt_amdir'};
    $amdir =~ s!globus/amdir!gpt_amdir!;
    if (-d "$amdir") {
      Grid::GPT::FilelistFunctions::mkinstalldir("$me->{'installdir'}/share/globus");
      Grid::GPT::FilelistFunctions::mkinstalldir("$me->{'installdir'}/share/globus/aclocal");
      Grid::GPT::FilelistFunctions::mkinstalldir("$me->{'installdir'}/share/globus/flavors");
    }

    return
  }
  if ($args{'mode'} eq 'build' ) {
    Grid::GPT::FilelistFunctions::mkinstalldir($me->{'builddir'});
    return
  }
  if ($args{'mode'} eq 'bundle' ) {
    Grid::GPT::FilelistFunctions::mkinstalldir($me->{'bindir'});
    return
  }
  if ($args{'mode'} eq 'tmp' ) {
    Grid::GPT::FilelistFunctions::mkinstalldir($me->{'tmpdir'});
    my $result = `chmod 700 $me->{'tmpdir'}`;
    return
  }

}

sub _init_builddir {
  my ($me) =@_;

  $me->{'builddir'} = defined $me->{'builddir'} ? $me->{'builddir'} : "./BUILD";
  $me->{'bindir'} = defined $me->{'bindir'} ? $me->{'bindir'} : "./bundle_pkgs";
  $me->{'srcdir'} = defined $me->{'srcdir'} ? $me->{'srcdir'} : "./source";
}

sub _init_installdirs {
  my ($me) =@_;

  $me->{'installdir'} = defined $me->{'installdir'} ? 
    $me->{'installdir'} : $globus_prefix;

  die "ERROR: GPT_INSTALL_LOCATION needs to be set before running this script.
Or use the -location switch"
    if ! defined $me->{'installdir'};

  # Determine what kind of package directory we have

  $me->{'bundledir'} = "$me->{'installdir'}/share/globus/bundles";
  $me->{'pkgdir'} = "$me->{'installdir'}/share/globus/packages";
  $me->{'flavordir'} = "$me->{'installdir'}/share/globus/flavors";
  $me->{'setupdir'} = "$me->{'installdir'}/share/globus/packages/setup";
  $me->{'pkg_confdir'} = "${pkg_confdir}";
}

sub cleanbuilddir {
  my ($me) = @_;

  return system("rm -rf $me->{'builddir'}");
}

sub cleantmp() {
  my ($me) = @_;

  my $top = $me->{'tmpdir'};
  opendir(DIR, $top);
  my @contents = readdir DIR;
  closedir DIR;


  my @dirs = grep { -d "$top/$_" and ! m!^\.! } @contents;
  my @files = grep { ! -d $_ } map { "$top/$_" } @contents;

  for my $f (@files) {
    unlink($f) or warn "WARNING: couldn't unlink $f: $!";
  }

  for my $d (@dirs) {
    cleandir("$top/$d");
  }

  rmdir $top;
}

sub AUTOLOAD {
  use vars qw($AUTOLOAD);
  my $self = shift;
  my $type = ref($self) || croak "$self is not an obj";
  my $name = $AUTOLOAD;
  $name =~ s/.*://;   # strip fully-qualified portion
  unless (exists $self->{$name} ) {
    croak "Can't access `$name' field in obj of class $type";
  } 
  if (@_) {
    return $self->{$name} = shift;
  } else {
    return $self->{$name};
  } 
}


sub DESTROY {}
END { }       # module clean-up code here (global destructor)

1;
__END__
